@@ -1,5 +1,5 @@
 """
-Copyright (C) 2021 Mayank Vats
+Copyright (C) 2021-2022 Mayank Vats
 See license.txt
 
 This program is free software: you can redistribute it and/or modify
@@ -16,11 +16,12 @@ You should have received a copy of the GNU General Public License v3
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 __author__ = "Mayank Vats"
-__email__ = "testpass.py@gmail.com"
-__Description__ = "AuthAlpha: A package to manage Hashing for your projects."
-__version__ = "0.8alpha"
+__email__ = "dev-theorist.e5xna@simplelogin.com"
+__Description__ = "AuthAlpha: A package to manage Hashing and OTP generation."
+__version__ = "0.7alpha"
 
 """
 
 from AuthAlpha.Password_Hashing import PassHashing
 from AuthAlpha.Non_Password_Hashing import NonPassHashing
+from AuthAlpha.OTPMethods import TwoFactorAuth
